@@ -194,6 +194,8 @@
 #include "token_info-5.22.0.h"
 #elif PERL_VERSION == 22 && PERL_SUBVERSION == 1
 #include "token_info-5.22.0.h"
+#elif PERL_VERSION == 22 && PERL_SUBVERSION == 2
+#include "token_info-5.22.0.h"
 #elif PERL_VERSION == 22
 #include "token_info-5.22.0.h"
 #elif PERL_VERSION == 23 && PERL_SUBVERSION == 0
@@ -214,7 +216,11 @@
 #include "token_info-5.23.4.h"
 #elif PERL_VERSION == 23 && PERL_SUBVERSION == 8
 #include "token_info-5.23.8.h"
-#elif PERL_VERSION > 23 || (PERL_VERSION == 23 && PERL_SUBVERSION > 8)
+#elif PERL_VERSION == 23 && PERL_SUBVERSION == 9
+#include "token_info-5.23.8.h"
+#elif PERL_VERSION == 24 && PERL_SUBVERSION == 0
+#include "token_info-5.24.0.h"
+#elif PERL_VERSION > 24 || (PERL_VERSION == 24 && PERL_SUBVERSION > 0)
 #include "token_info-latest.h"
 #else
 #error "No support for this perl version"
